<?php

/**
 * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
 * @link          http://cakephp.org CakePHP(tm) Project
 * @since         0.10.8
 * @license       http://www.opensource.org/licenses/mit-license.php MIT License
 */
/**
 * Configure paths required to find CakePHP + general filepath
 * constants
 */
require __DIR__ . '/paths.php';

// Use composer to load the autoloader.
require ROOT . DS . 'vendor' . DS . 'autoload.php';

/**
 * Bootstrap CakePHP.
 *
 * Does the various bits of setup that CakePHP needs to do.
 * This includes:
 *
 * - Registering the CakePHP autoloader.
 * - Setting the default application paths.
 */
require CORE_PATH . 'config' . DS . 'bootstrap.php';

// You can remove this if you are confident you have intl installed.
if (!extension_loaded('intl')) {
    trigger_error('You must enable the intl extension to use CakePHP.', E_USER_ERROR);
}

use Cake\Cache\Cache;
use Cake\Console\ConsoleErrorHandler;
use Cake\Core\App;
use Cake\Core\Configure;
use Cake\Core\Configure\Engine\PhpConfig;
use Cake\Core\Plugin;
use Cake\Database\Type;
use Cake\Datasource\ConnectionManager;
use Cake\Error\ErrorHandler;
use Cake\Log\Log;
use Cake\Mailer\Email;
use Cake\Network\Request;
use Cake\Routing\DispatcherFactory;
use Cake\Utility\Inflector;
use Cake\Utility\Security;

/**
 * Read configuration file and inject configuration into various
 * CakePHP classes.
 *
 * By default there is only one configuration file. It is often a good
 * idea to create multiple configuration files, and separate the configuration
 * that changes from configuration that does not. This makes deployment simpler.
 */
try {
    Configure::config('default', new PhpConfig());
    Configure::load('app', 'default', false);
} catch (\Exception $e) {
    exit($e->getMessage() . "\n");
}

// Load an environment local configuration file.
// You can use a file like app_local.php to provide local overrides to your
// shared configuration.
//Configure::load('app_local', 'default');
// When debug = false the metadata cache should last
// for a very very long time, as we don't want
// to refresh the cache while users are doing requests.
if (!Configure::read('debug')) {
    Configure::write('Cache._cake_model_.duration', '+1 years');
    Configure::write('Cache._cake_core_.duration', '+1 years');
}

/**
 * Set server timezone to UTC. You can change it to another timezone of your
 * choice but using UTC makes time calculations / conversions easier.
 */
date_default_timezone_set('UTC');

/**
 * Configure the mbstring extension to use the correct encoding.
 */
mb_internal_encoding(Configure::read('App.encoding'));

/**
 * Set the default locale. This controls how dates, number and currency is
 * formatted and sets the default language to use for translations.
 */
DispatcherFactory::add('LocaleSelector');

//ini_set('intl.default_locale', Configure::read('fr_FR'));

/**
 * Register application error and exception handlers.
 */
$isCli = PHP_SAPI === 'cli';
if ($isCli) {
    (new ConsoleErrorHandler(Configure::read('Error')))->register();
} else {
    (new ErrorHandler(Configure::read('Error')))->register();
}

// Include the CLI bootstrap overrides.
if ($isCli) {
    require __DIR__ . '/bootstrap_cli.php';
}

/**
 * Set the full base URL.
 * This URL is used as the base of all absolute links.
 *
 * If you define fullBaseUrl in your config file you can remove this.
 */
if (!Configure::read('App.fullBaseUrl')) {
    $s = null;
    if (env('HTTPS')) {
        $s = 's';
    }

    $httpHost = env('HTTP_HOST');
    if (isset($httpHost)) {
        Configure::write('App.fullBaseUrl', 'http' . $s . '://' . $httpHost);
    }
    unset($httpHost, $s);
}

Cache::config(Configure::consume('Cache'));
ConnectionManager::config(Configure::consume('Datasources'));
Email::configTransport(Configure::consume('EmailTransport'));
Email::config(Configure::consume('Email'));
Log::config(Configure::consume('Log'));
Security::salt(Configure::consume('Security.salt'));

/**
 * The default crypto extension in 3.0 is OpenSSL.
 * If you are migrating from 2.x uncomment this code to
 * use a more compatible Mcrypt based implementation
 */
//Security::engine(new \Cake\Utility\Crypto\Mcrypt());

/**
 * Setup detectors for mobile and tablet.
 */
Request::addDetector('mobile', function ($request) {
    $detector = new \Detection\MobileDetect();
    return $detector->isMobile();
});
Request::addDetector('tablet', function ($request) {
    $detector = new \Detection\MobileDetect();
    return $detector->isTablet();
});

/**
 * Custom Inflector rules, can be set to correctly pluralize or singularize
 * table, model, controller names or whatever other string is passed to the
 * inflection functions.
 *
 * Inflector::rules('plural', ['/^(inflect)or$/i' => '\1ables']);
 * Inflector::rules('irregular', ['red' => 'redlings']);
 * Inflector::rules('uninflected', ['dontinflectme']);
 * Inflector::rules('transliteration', ['/å/' => 'aa']);
 */
/**
 * Plugins need to be loaded manually, you can either load them one by one or all of them in a single call
 * Uncomment one of the lines below, as you need. make sure you read the documentation on Plugin to use more
 * advanced ways of loading plugins
 *
 * Plugin::loadAll(); // Loads all plugins at once
 * Plugin::load('Migrations'); //Loads a single plugin named Migrations
 *
 */
Plugin::load('Migrations');

// Only try to load DebugKit in development mode
// Debug Kit should not be installed on a production system
if (Configure::read('debug')) {
    Plugin::load('DebugKit', ['bootstrap' => true]);
}

/**
 * Connect middleware/dispatcher filters.
 */
DispatcherFactory::add('Asset');
DispatcherFactory::add('Routing');
DispatcherFactory::add('ControllerFactory');

/**
 * Enable default locale format parsing.
 * This is needed for matching the auto-localized string output of Time() class when parsing dates.
 *
 * Also enable immutable time objects in the ORM.
 */
Type::build('time')
        ->useImmutable()
        ->useLocaleParser();
Type::build('date')
        ->useImmutable()
        ->useLocaleParser();
Type::build('datetime')
        ->useImmutable()
        ->useLocaleParser();


\Cake\Core\Plugin::load('BootstrapUI');



/**
 * Connect middleware/dispatcher filters.
 */
/**
 * Integer to limit number of elements in the carousel SPOTLIGHT ON.
 */
Configure::write('CAROUSEL_FOCUS_TOP_APPS', 3);
/**
 * Column's number for software summary col sm.
 */
Configure::write('SOFTWARE_SUMMARY_COL-SM', 6);
/**
 * Column's number for software summary col xs.
 */
Configure::write('SOFTWARE_SUMMARY_COL-XS', 12);
/**
 * Column's number for software summary col md.
 */
Configure::write('SOFTWARE_SUMMARY_COL-MD', 3);
/**
 * Column's number for software summary col lg.
 */
Configure::write('SOFTWARE_SUMMARY_COL-LG', 3);
/**
 * Integer to limit number of element in TOP DOWNLOAD section
 */
Configure::write("LIMIT_TOP_DOWNLOADS", 10);

/**
 * Integer to limit number  of elements in LAST ADDED section.
 */
Configure::write("LIMIT_LAST_ADDED", 10);

/**
 * Max points for a software score.
 */
Configure::write("TOTAL_POINTS_SCORE", 100);

# Max size to allow upload
Configure::write("MAX_IMAGE_SIZE", 50);


/**
 * Max number of elements (screenshots/review...) display
 */
Configure::write('MAX_DISPLAY', 3);


/**
 * Version  of comptoir
 */
Configure::write('VERSION',
    [
    "footer"=>     "v1.0.1"
    ]
);


Configure::write(
    'Softwares',
    [
        'scores' => [
            'score_low' => 25,
            'score_medium' => 50,
            'score_high' => 75,
            'score_best' => 100
        ],
    ]

);

Configure::write('Stamps',
    [
        'unstamped',
        'stampted'
    ]
);

/**
 * Integer to determine color red of Software's mark
 */
Configure::write("LOW_MARK", 25);

/**
 * Integer to determine color orange of Software's mark
 */
Configure::write("MEDIUM_MARK", 50);

/**
 * Integer to determine color yellow/green of Software's mark
 */
Configure::write("HIGH_MARK", 75);

Configure::write(
    'Softwares',
    [
        'scores' => [
            'score_medium' => 50,
            'score_low' => 25,
            'score_high' => 75,
            'score_best' => 100
        ]
    ]
);

/**
 * Metrics from source code
 */
Configure::write("SOURCE_CODE_METRICS",
                [   "project_age",
                    "delta_commit_one_month",
                    "delta_commit_twelve_month",
                    "last_commit_age",
                    "high_committer_percent",
                    "number_of_contributors"]);
/**
 * Metrics from comptoir
 */
Configure::write("COMPTOIR_METRICS",
                [   "declared_users",
                    "average_review_score",
                    "screenshots",
                    "code_gouv_label"]);

try {
    Configure::config('default', new PhpConfig());
    Configure::load('comptoir', 'default', false);
} catch (\Exception $e) {
    exit($e->getMessage() . "\n");
}